ShieldedCache v2.1.1 ShieldedCache.TaskManager.TaskSet View Source
ShieldedCache.TaskManager.TaskSet
A GenServer process that holds in it’s state a unique set of tasks.
The TaskSet defines functions to add task refs, finish task refs, and get all the current task refs.
Link to this section Summary
Types
A representation of the state of the TaskSet
A representation of the tasks saved in the TaskSet state
Link to this section Types
state() :: {Map.t(), list(), Map.t(), non_neg_integer(), non_neg_integer()}
A representation of the state of the TaskSet
A representation of the tasks saved in the TaskSet state
Link to this section Functions
add_task/2
Adds a task reference to the specified task set.
Returns a specification to start this module under a supervisor.
See Supervisor.
Finishes the specified task reference in the specified task set.
Gets all of the currently running task references in the specified task set.
Gets all of the task references in the specified task set.
Returns a task back to the task sets and removes it from currently running tasks. This will also check if the task has exceeded the maximum number of retries (5).
start_link(opts :: Keyword.t()) :: GenServer.on_start()
Starts the TaskSet.
Starts a task in the specified task set. This will move the task to a list of currently running fetch tasks.